@@ -43,14 +43,17 @@ pub use ockam_macros::{AsyncTryClone, Message};
 
 extern crate futures_util;
 
+mod access_control;
 pub mod compat;
 mod error;
 mod message;
 mod processor;
 mod routing;
 mod uint;
+pub mod vault;
 mod worker;
 
+pub use access_control::*;
 pub use error::*;
 pub use message::*;
 pub use processor::*;
