@@ -9,7 +9,6 @@ use core::{
     fmt::{self, Debug, Display, Formatter},
     ops::{Deref, DerefMut},
 };
-use ockam_message_derive::Message;
 use serde::{de::DeserializeOwned, Deserialize, Serialize};
 
 /// Alias of the type used for encoded data.
@@ -185,6 +184,12 @@ impl<M: Message> Routed<M> {
     pub fn payload(&self) -> &[u8] {
         &self.local_msg.transport().payload
     }
+
+    /// Get underlying binary message payload
+    #[inline]
+    pub fn take_payload(self) -> Vec<u8> {
+        self.local_msg.into_transport_message().payload
+    }
 }
 
 impl<M: Message> Deref for Routed<M> {
@@ -228,7 +233,7 @@ impl<M: Message + Display> Display for Routed<M> {
 /// This is especially useful for implementing middleware workers
 /// which need access to the route information of a message, without
 /// understanding its payload.
-#[derive(Clone, Debug, PartialEq, Eq, Message)]
+#[derive(Clone, Debug, PartialEq, Eq, crate::Message)]
 pub struct Any;
 
 impl Display for Any {
